Commit: 8afcecdf1fd1a7fe7dad232b58168d321f7086a1
Author: Xavier Hallade
Date:   Mon Jan 23 18:35:43 2023 +0100
Branches: master
https://developer.blender.org/rB8afcecdf1fd1a7fe7dad232b58168d321f7086a1

Cycles: update Intel Graphics compiler to 101.4032 on Windows

A noticeable (>5%) performance regression in oneAPI backend came with
a501a2dbff797829b61f21c5aeb9d19dba3e3874. Updating to latest graphics
compiler from driver 101.4032 fixes it.

I've tested it with current min-supported drivers and it runs well but
since compatibility of graphics compiler with older drivers isn't
guaranteed, I'm also bumping the min-supported driver versions.

If end-users consider latest drivers too fresh to switch to (version
isn't released as stable on Linux as of today but should be before
Blender 3.5 release), CYCLES_ONEAPI_ALL_DEVICES=1 env variable can be
used.

Intel Graphics Compiler on Linux will be updated in a later commit
so we can then close D16984.

Reviewed By: sergey, LazyDodo

===================================================================

M       build_files/config/pipeline_config.yaml
M       intern/cycles/blender/addon/properties.py
M       intern/cycles/device/oneapi/device_impl.cpp

===================================================================

diff --git a/build_files/config/pipeline_config.yaml 
b/build_files/config/pipeline_config.yaml
index 88ca5108e8b..29c0b131b3d 100644
--- a/build_files/config/pipeline_config.yaml
+++ b/build_files/config/pipeline_config.yaml
@@ -63,7 +63,7 @@ buildbot:
     optix:
         version: '7.3.0'
     ocloc:
-        version: '101.3430'
+        version: '101.4032'
     cmake:
         default:
             version: any
diff --git a/intern/cycles/blender/addon/properties.py 
b/intern/cycles/blender/addon/properties.py
index 62d5ce8a572..eed51eed95f 100644
--- a/intern/cycles/blender/addon/properties.py
+++ b/intern/cycles/blender/addon/properties.py
@@ -1680,10 +1680,10 @@ class CyclesPreferences(bpy.types.AddonPreferences):
                 import sys
                 if sys.platform.startswith("win"):
                     col.label(text="Requires Intel GPU with Xe-HPG 
architecture", icon='BLANK1')
-                    col.label(text="and Windows driver version 101.3430 or 
newer", icon='BLANK1')
+                    col.label(text="and Windows driver version 101.4032 or 
newer", icon='BLANK1')
                 elif sys.platform.startswith("linux"):
                     col.label(text="Requires Intel GPU with Xe-HPG 
architecture and", icon='BLANK1')
-                    col.label(text="  - intel-level-zero-gpu version 1.3.23904 
or newer", icon='BLANK1')
+                    col.label(text="  - intel-level-zero-gpu version 1.3.24931 
or newer", icon='BLANK1')
                     col.label(text="  - oneAPI Level-Zero Loader", 
icon='BLANK1')
             elif device_type == 'METAL':
                 col.label(text="Requires Apple Silicon with macOS 12.2 or 
newer", icon='BLANK1')
diff --git a/intern/cycles/device/oneapi/device_impl.cpp 
b/intern/cycles/device/oneapi/device_impl.cpp
index edffd9525b1..1915ffc862c 100644
--- a/intern/cycles/device/oneapi/device_impl.cpp
+++ b/intern/cycles/device/oneapi/device_impl.cpp
@@ -631,9 +631,9 @@ bool OneapiDevice::enqueue_kernel(KernelContext 
*kernel_context,
 /* Compute-runtime (ie. NEO) version is what gets returned by sycl/L0 on 
Windows
  * since Windows driver 101.3268. */
 /* The same min compute-runtime version is currently required across Windows 
and Linux.
- * For Windows driver 101.3430, compute-runtime version is 23904. */
-static const int lowest_supported_driver_version_win = 1013430;
-static const int lowest_supported_driver_version_neo = 23904;
+ * For Windows driver 101.4032, compute-runtime version is 24931. */
+static const int lowest_supported_driver_version_win = 1014032;
+static const int lowest_supported_driver_version_neo = 24931;
 
 int OneapiDevice::parse_driver_build_version(const sycl::device &device)
 {

_______________________________________________
Bf-blender-cvs mailing list
Bf-blender-cvs@blender.org
List details, subscription details or unsubscribe:
https://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to